@@ -26,8 +26,11 @@ class _GlobalOptions(TypedDict):
     integer_interpolation: IntegerInterpolation
     float_interpolation: FloatInterpolation
     temporary_folder: StrPath | None
+    raise_on_incomplete_blocks: bool
     raise_on_multiple_occurrences: bool
     fill_0_for_missing_computation_channels: bool
+    ignore_invalidation_bits: bool
+    check_unsaved_display_file: bool
 
 
 GLOBAL_OPTIONS: Final[_GlobalOptions] = {
@@ -38,8 +41,11 @@ GLOBAL_OPTIONS: Final[_GlobalOptions] = {
     "integer_interpolation": IntegerInterpolation.REPEAT_PREVIOUS_SAMPLE,
     "float_interpolation": FloatInterpolation.LINEAR_INTERPOLATION,
     "temporary_folder": None,
+    "raise_on_incomplete_blocks": True,
     "raise_on_multiple_occurrences": True,
     "fill_0_for_missing_computation_channels": False,
+    "ignore_invalidation_bits": False,
+    "check_unsaved_display_file": False,
 }
 
 _Opt = Literal[
@@ -50,8 +56,11 @@ _Opt = Literal[
     "integer_interpolation",
     "float_interpolation",
     "temporary_folder",
+    "raise_on_incomplete_blocks",
     "raise_on_multiple_occurrences",
     "fill_0_for_missing_computation_channels",
+    "ignore_invalidation_bits",
+    "check_unsaved_display_file",
 ]
 
 
@@ -66,8 +75,11 @@ def set_global_option(opt: _Opt, value: Any) -> None:
     elif opt in (
         "use_display_names",
         "single_bit_uint_as_bool",
+        "raise_on_incomplete_blocks",
         "raise_on_multiple_occurrences",
         "fill_0_for_missing_computation_channels",
+        "ignore_invalidation_bits",
+        "check_unsaved_display_file",
     ):
         GLOBAL_OPTIONS[opt] = bool(value)
     elif opt == "integer_interpolation":
