@@ -16,6 +16,7 @@ import struct
 import sys
 from textwrap import indent
 from threading import Thread
+import time
 from time import sleep
 import traceback
 from traceback import format_exc
@@ -38,6 +39,9 @@ for key in ("breakpoint", "compile", "eval", "exec", "input", "open"):
 ERROR_ICON = None
 RANGE_INDICATOR_ICON = None
 NO_ERROR_ICON = None
+NO_ICON = None
+COMPUTED_ICON = None
+USER_EDITED_ICON = None
 
 COMPUTED_FUNCTION_ERROR_VALUE = float("nan")
 
@@ -177,7 +181,7 @@ def excepthook(exc_type, exc_value, tracebackobj):
     print("".join(traceback.format_tb(tracebackobj)))
     print(f"{exc_type}: {exc_value}")
 
-    ErrorDialog(message=errmsg, trace=msg, title="The following error was triggered").exec_()
+    ErrorDialog(message=errmsg, trace=msg, title="The following error was triggered").exec()
 
 
 def run_thread_with_progress(widget, target, kwargs, factor=100, offset=0, progress=None):
@@ -216,7 +220,7 @@ def run_thread_with_progress(widget, target, kwargs, factor=100, offset=0, progr
 
 class QWorkerThread(QtCore.QThread):
     error = QtCore.Signal(object)
-    result = QtCore.Signal(object)
+    output = QtCore.Signal(object)
 
     # will forward to the progress dialog
     setLabelText = QtCore.Signal(str)
@@ -231,7 +235,7 @@ class QWorkerThread(QtCore.QThread):
         [
             "finished",
             "error",
-            "result",
+            "output",
             "setLabelText",
             "setWindowTitle",
             "setWindowIcon",
@@ -249,7 +253,7 @@ class QWorkerThread(QtCore.QThread):
         self.signals = self.SIGNALS_TEMPLATE(
             self.finished,
             self.error,
-            self.result,
+            self.output,
             self.setLabelText,
             self.setWindowTitle,
             self.setWindowIcon,
@@ -276,7 +280,7 @@ class QWorkerThread(QtCore.QThread):
             exctype, value = sys.exc_info()[:2]
             self.error.emit((exctype, value, traceback.format_exc()))
         else:
-            self.result.emit(result)
+            self.output.emit(result)
         finally:
             self.kwargs = self.args = None
 
@@ -289,7 +293,7 @@ class ProgressDialog(QtWidgets.QProgressDialog):
         super().__init__(*args, **kwargs)
         self.thread = None
         self.error = None
-        self.result = None
+        self.output = None
         self.close_on_finish = True
         self.hide_on_finish = False
 
@@ -301,7 +305,7 @@ class ProgressDialog(QtWidgets.QProgressDialog):
         self, target, args, kwargs, wait_here=False, close_on_finish=True, hide_on_finish=False
     ):
         self.show()
-        self.result = None
+        self.output = None
         self.error = None
         self.thread_finished = False
 
@@ -309,7 +313,7 @@ class ProgressDialog(QtWidgets.QProgressDialog):
         self.hide_on_finish = hide_on_finish
 
         self.thread = QWorkerThread(target, *args, parent=self, **kwargs)
-        self.thread.result.connect(self.receive_result)
+        self.thread.output.connect(self.receive_output)
         self.thread.finished.connect(self.thread_complete)
         self.thread.error.connect(self.receive_error)
         self.thread.setLabelText.connect(self.setLabelText)
@@ -326,7 +330,7 @@ class ProgressDialog(QtWidgets.QProgressDialog):
             self.thread.finished.connect(loop.quit)
             loop.exec()
 
-        return self.result
+        return self.output
 
     def setLabelText(self, text):
         super().setLabelText(text)
@@ -334,8 +338,8 @@ class ProgressDialog(QtWidgets.QProgressDialog):
     def processEvents(self):
         pass
 
-    def receive_result(self, result):
-        self.result = result
+    def receive_output(self, output):
+        self.output = output
 
     def receive_error(self, error):
         self.error = error
@@ -345,7 +349,7 @@ class ProgressDialog(QtWidgets.QProgressDialog):
         if self.hide_on_finish:
             self.hide()
 
-        self.thread.result.disconnect(self.receive_result)
+        self.thread.output.disconnect(self.receive_output)
         self.thread.finished.disconnect(self.thread_complete)
         self.thread.error.disconnect(self.receive_error)
         self.thread.setLabelText.disconnect(self.setLabelText)
@@ -466,15 +470,7 @@ def compute_signal(
     functions,
     global_variables="",
 ):
-    required_channels = {}
-    for key, sig in measured_signals.items():
-        signal = sig.physical(copy=False, ignore_value2text_conversions=True)
-        if signal.samples.dtype.kind in "fui":
-            required_channels[key] = signal
-        else:
-            required_channels[key] = sig
-
-    measured_signals = required_channels
+    use_raw_values = description.get("use_raw_values", {})
 
     type_ = description["type"]
 
@@ -511,7 +507,17 @@ def compute_signal(
             for arg, alternative_names in description["args"].items():
                 for name in alternative_names:
                     if name in measured_signals:
-                        signals.append(measured_signals[name])
+                        sig = measured_signals[name]
+
+                        if use_raw_values.get(arg, False):
+                            signals.append(sig)
+                        else:
+                            signal = sig.physical(copy=False, ignore_value2text_conversions=True)
+                            if signal.samples.dtype.kind in "fui":
+                                signals.append(signal)
+                            else:
+                                signals.append(sig)
+
                         found_args.append(arg)
                         break
                     else:
@@ -617,7 +623,7 @@ def compute_signal(
                     samples.append(current_sample)
 
                 result = Signal(
-                    name="_",
+                    name=description["channel_name"] or "_",
                     samples=samples,
                     timestamps=common_timebase + shift,
                     flags=Signal.Flags.computed,
@@ -648,7 +654,7 @@ def compute_signal(
                     common_timebase = common_timebase[-len(samples) :]
 
                 result = Signal(
-                    name="_",
+                    name=description["channel_name"] or "_",
                     samples=samples,
                     timestamps=common_timebase + shift,
                     flags=Signal.Flags.computed,
@@ -1212,6 +1218,7 @@ def generate_python_function_globals() -> dict:
         "pd": pd,
         "random": random,
         "struct": struct,
+        "time": time,
         "__builtins__": _BUILTINS,
     }
     try:
