@@ -409,7 +409,7 @@ class FormatedAxis(pg.AxisItem):
 
         lv = self.linkedView()
 
-        factor = self._settings.value("zoom_wheel_factor", 0.165, type=float)
+        factor = self._settings.value("plot/zoom/wheel_factor", 0.165, type=float)
 
         if lv is None:
             # this is one of the individual axis
@@ -417,13 +417,7 @@ class FormatedAxis(pg.AxisItem):
             pos = event.pos()
             rect = self.boundingRect()
 
-            zoom_y_mode = self._settings.value("zoom_y_mode", "")
-
-            if not zoom_y_mode:
-                if self._settings.value("zoom_y_center_on_cursor", False, type=bool):
-                    zoom_y_mode = "center_on_cursor"
-                else:
-                    zoom_y_mode = "center_on_mouse"
+            zoom_y_mode = self._settings.value("plot/zoom/y_mode", "center_on_mouse")
 
             if zoom_y_mode == "pin_zero_level":
                 plot, uuid = self.linked_signal
@@ -455,8 +449,8 @@ class FormatedAxis(pg.AxisItem):
                 delta = sig_y_top - sig_y_bottom
 
                 if event.delta() > 0:
-                    end = sig_y_top - 1 / factor * delta
-                    start = sig_y_bottom + 1 / factor * delta
+                    end = sig_y_top - factor * delta
+                    start = sig_y_bottom + factor * delta
                 else:
                     end = sig_y_top + factor * delta
                     start = sig_y_bottom - factor * delta
@@ -473,7 +467,7 @@ class FormatedAxis(pg.AxisItem):
                 delta = self.range[-1] - self.range[0]
 
                 if event.delta() > 0:
-                    delta = 1 / (1 + factor) * delta
+                    delta = (1 - factor) * delta
                 else:
                     delta = (1 + factor) * delta
 
@@ -497,13 +491,7 @@ class FormatedAxis(pg.AxisItem):
                     pos = event.pos()
                     rect = self.boundingRect()
 
-                    zoom_y_mode = self._settings.value("zoom_y_mode", "")
-
-                    if not zoom_y_mode:
-                        if self._settings.value("zoom_y_center_on_cursor", False, type=bool):
-                            zoom_y_mode = "center_on_cursor"
-                        else:
-                            zoom_y_mode = "center_on_mouse"
+                    zoom_y_mode = self._settings.value("plot/zoom/y_mode", "center_on_mouse")
 
                     if zoom_y_mode == "pin_zero_level":
                         plot, uuid = self.linked_signal
@@ -732,6 +720,11 @@ class FormatedAxis(pg.AxisItem):
                     values.append(val)
                     strings.append(strn)
 
+        if self._settings.value("grid_major_ticks_only", False, type=bool):
+            tickLevels = tickLevels[:1]
+            if tickStrings is not None:
+                tickStrings = tickStrings[:1]
+
         ## determine mapping between tick values and local coordinates
         dif = self.range[1] - self.range[0]
         if dif == 0:
@@ -948,3 +941,30 @@ class FormatedAxis(pg.AxisItem):
             )
 
         return (axisSpec, tickSpecs, textSpecs)
+
+    def boundingRect(self):
+        m = 0
+        hide_overlapping_labels = self.style["hideOverlappingLabels"]
+        if hide_overlapping_labels is True:
+            pass  # skip further checks
+        elif hide_overlapping_labels is False:
+            m = 15
+        else:
+            try:
+                m = int(self.style["hideOverlappingLabels"])
+            except ValueError:
+                pass  # ignore any non-numeric value
+
+        rect = self.mapRectFromParent(self.geometry())
+        ## extend rect if ticks go in negative direction
+        ## also extend to account for text that flows past the edges
+        tl = self.style["tickLength"]
+        if self.orientation == "left":
+            rect = rect.adjusted(0, -m, -min(0, tl), m)
+        elif self.orientation == "right":
+            rect = rect.adjusted(min(0, tl), -m, 0, m)
+        elif self.orientation == "top":
+            rect = rect.adjusted(-m, 0, m, -min(0, tl))
+        elif self.orientation == "bottom":
+            rect = rect.adjusted(-m, min(0, tl), m, 0)
+        return rect
