@@ -11,6 +11,7 @@ import pyqtgraph as pg
 from PySide6 import __version__ as pyside6_version
 from PySide6 import QtCore, QtGui, QtWidgets
 
+from ...blocks.options import set_global_option
 from ...version import __version__ as libversion
 from .. import utils
 from ..dialogs.bus_database_manager import BusDatabaseManagerDialog
@@ -33,16 +34,20 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         WithMDIArea.__init__(self, comparison=True)
         self.setupUi(self)
         self._settings = QtCore.QSettings()
-        self._settings.setValue("current_theme", self._settings.value("theme", "Light"))
+        self._settings.setValue("interface/current_theme", self._settings.value("interface/theme", "Light"))
         self._light_palette = self.palette()
 
         self.ignore_value2text_conversions = self._settings.value("ignore_value2text_conversions", False, type=bool)
 
         self.display_cg_name = self._settings.value("display_cg_name", False, type=bool)
+        self.check_unsaved_display = self._settings.value("check_unsaved_display", True, type=bool)
+        self.ignore_invalidation_bits = self._settings.value("ignore_invalidation_bits", False, type=bool)
 
-        self.integer_interpolation = int(self._settings.value("integer_interpolation", "2 - hybrid interpolation")[0])
+        self.integer_interpolation = int(
+            self._settings.value("mdf/integer_interpolation", "2 - hybrid interpolation")[0]
+        )
 
-        self.float_interpolation = int(self._settings.value("float_interpolation", "1 - linear interpolation")[0])
+        self.float_interpolation = int(self._settings.value("mdf/float_interpolation", "1 - linear interpolation")[0])
 
         self.batch = BatchWidget(
             self.ignore_value2text_conversions,
@@ -176,7 +181,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         subplot_action = QtGui.QAction("Sub-windows", menu)
         subplot_action.setCheckable(True)
 
-        state = self._settings.value("subplots", True, type=bool)
+        state = self._settings.value("mdf/subwindows", True, type=bool)
         subplot_action.toggled.connect(self.set_subplot_option)
         subplot_action.triggered.connect(self.set_subplot_option)
         subplot_action.setChecked(state)
@@ -185,7 +190,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         # Link sub-windows X-axis
         subplot_action = QtGui.QAction("Link sub-windows X-axis", menu)
         subplot_action.setCheckable(True)
-        state = self._settings.value("subplots_link", True, type=bool)
+        state = self._settings.value("mdf/subwindows_link", True, type=bool)
         subplot_action.toggled.connect(self.set_subplot_link_option)
         subplot_action.setChecked(state)
         menu.addAction(subplot_action)
@@ -197,6 +202,13 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         subplot_action.setChecked(self.ignore_value2text_conversions)
         menu.addAction(subplot_action)
 
+        # invalidation bits
+        subplot_action = QtGui.QAction("Ignore invalidation bits", menu)
+        subplot_action.setCheckable(True)
+        subplot_action.toggled.connect(self.set_invalidation_bits_option)
+        subplot_action.setChecked(self.ignore_invalidation_bits)
+        menu.addAction(subplot_action)
+
         # Show Channel Group Name
         subplot_action = QtGui.QAction("Display Channel Group Name", menu)
         subplot_action.setCheckable(True)
@@ -204,6 +216,13 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         subplot_action.setChecked(self.display_cg_name)
         menu.addAction(subplot_action)
 
+        # cehck for unsaved display file
+        subplot_action = QtGui.QAction("Check for unsaved display changes", menu)
+        subplot_action.setCheckable(True)
+        subplot_action.toggled.connect(self.set_check_unsaved_display)
+        subplot_action.setChecked(self.check_unsaved_display)
+        menu.addAction(subplot_action)
+
         # plot background
         plot_background_option = QtGui.QActionGroup(self)
 
@@ -213,7 +232,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             plot_background_option.addAction(action)
             action.triggered.connect(partial(self.set_plot_background, option))
 
-            if option == self._settings.value("plot_background", "Black"):
+            if option == self._settings.value("plot/background", "Black"):
                 action.setChecked(True)
                 action.triggered.emit()
 
@@ -230,7 +249,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             plot_xaxis_option.addAction(action)
             action.triggered.connect(partial(self.set_plot_xaxis, option))
 
-            if option == self._settings.value("plot_xaxis", "seconds"):
+            if option == self._settings.value("plot/xaxis_units", "seconds"):
                 action.setChecked(True)
                 action.triggered.emit()
 
@@ -247,7 +266,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             theme_option.addAction(action)
             action.triggered.connect(partial(self.set_theme, option))
 
-            if option == self._settings.value("theme", "Light"):
+            if option == self._settings.value("interface/theme", "Light"):
                 action.setChecked(True)
                 action.triggered.emit()
 
@@ -270,7 +289,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             step_option.addAction(action)
             action.triggered.connect(partial(self.set_line_interconnect, option))
 
-            if option == self._settings.value("line_interconnect", "line"):
+            if option == self._settings.value("plot/curve/line_interconnect", "line"):
                 action.setChecked(True)
                 action.triggered.emit()
 
@@ -302,7 +321,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             theme_option.addAction(action)
             action.triggered.connect(partial(self.set_integer_interpolation, option))
 
-            if option == self._settings.value("integer_interpolation", "2 - hybrid interpolation"):
+            if option == self._settings.value("mdf/integer_interpolation", "2 - hybrid interpolation"):
                 action.setChecked(True)
                 action.triggered.emit()
 
@@ -320,7 +339,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             theme_option.addAction(action)
             action.triggered.connect(partial(self.set_float_interpolation, option))
 
-            if option == self._settings.value("float_interpolation", "1 - linear interpolation"):
+            if option == self._settings.value("mdf/float_interpolation", "1 - linear interpolation"):
                 action.setChecked(True)
                 action.triggered.emit()
 
@@ -332,7 +351,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         # tabular interpolation
         subplot_action = QtGui.QAction("Tabular windows interpolation", menu)
         subplot_action.setCheckable(True)
-        state = self._settings.value("tabular_interpolation", True, type=bool)
+        state = self._settings.value("tabular/interpolation", True, type=bool)
         subplot_action.toggled.connect(self.set_tabular_interpolation_option)
         subplot_action.setChecked(state)
         menu.addAction(subplot_action)
@@ -343,7 +362,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
 
         action = QtGui.QAction("Color")
         action.triggered.connect(partial(self.edit_cursor_options, action=action))
-        color = self._settings.value("cursor_color", "white")
+        color = self._settings.value("plot/cursor/color", "white")
         icon = draw_color_icon(color)
         action.setIcon(icon)
         submenu.addAction(action)
@@ -853,11 +872,11 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
 
         menu.addActions(open_group.actions())
 
-        self.with_dots = self._settings.value("dots", False, type=bool)
+        self.with_dots = self._settings.value("plot/dots", False, type=bool)
         self.setWindowTitle(f"asammdf {libversion} [PID={os.getpid()}] - Single files")
 
-        self.set_subplot_option(self._settings.value("subplots", "Disabled"))
-        self.set_subplot_link_option(self._settings.value("subplots_link", "Disabled"))
+        self.set_subplot_option(self._settings.value("mdf/subwindows", "Disabled"))
+        self.set_subplot_link_option(self._settings.value("mdf/subwindows_link", "Disabled"))
         self.hide_missing_channels = False
         self.hide_disabled_channels = False
 
@@ -982,14 +1001,14 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
                 count = len(current_plot.plot.signals)
 
                 self.with_dots = new_setting_has_dots
-                self._settings.setValue("dots", self.with_dots)
+                self._settings.setValue("plot/dots", self.with_dots)
                 file_widget.set_line_style(with_dots=new_setting_has_dots)
                 self.set_line_style(with_dots=self.with_dots)
         else:
             widget = self.get_current_widget()
             if widget and isinstance(widget, Plot):
                 self.with_dots = not self.with_dots
-                self._settings.setValue("dots", self.with_dots)
+                self._settings.setValue("plot/dots", self.with_dots)
                 self.set_line_style(with_dots=self.with_dots)
 
     def show_sub_windows(self, mode):
@@ -1020,12 +1039,12 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
     def edit_cursor_options(self, checked=None, action=None):
         if action:
             if action.text() == "Color":
-                color = self._settings.value("cursor_color", "white")
+                color = self._settings.value("plot/cursor/color", "white")
                 color = QtWidgets.QColorDialog.getColor(color)
                 if not color.isValid():
                     return
 
-                self._settings.setValue("cursor_color", color.name())
+                self._settings.setValue("plot/cursor/color", color.name())
 
                 icon = draw_color_icon(color)
                 action.setIcon(icon)
@@ -1037,12 +1056,12 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
                 self._settings.setValue("show_cursor_horizontal_line", action.isChecked())
 
             elif action.text() == "Line width":
-                self._settings.setValue("cursor_line_width", action.defaultWidget().currentIndex() + 1)
+                self._settings.setValue("plot/cursor/line_width", action.defaultWidget().currentIndex() + 1)
 
         cursor_circle = self._settings.value("show_cursor_circle", False, type=bool)
         cursor_horizontal_line = self._settings.value("show_cursor_horizontal_line", False, type=bool)
-        cursor_line_width = self._settings.value("cursor_line_width", 1, type=int)
-        cursor_color = self._settings.value("cursor_color", "#e69138")
+        cursor_line_width = self._settings.value("plot/cursor/line_width", 1, type=int)
+        cursor_color = self._settings.value("plot/cursor/color", "#e69138")
 
         for i in range(self.files.count()):
             file = self.files.widget(i)
@@ -1052,7 +1071,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         if isinstance(state, str):
             state = True if state == "true" else False
         self.set_subplots(state)
-        self._settings.setValue("subplots", state)
+        self._settings.setValue("mdf/subwindows", state)
 
         count = self.files.count()
 
@@ -1060,7 +1079,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             self.files.widget(i).set_subplots(state)
 
     def set_plot_background(self, option):
-        self._settings.setValue("plot_background", option)
+        self._settings.setValue("plot/background", option)
         if option == "Black":
             pg.setConfigOption("background", "k")
             pg.setConfigOption("foreground", "w")
@@ -1069,7 +1088,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             pg.setConfigOption("foreground", "k")
 
     def set_integer_interpolation(self, option):
-        self._settings.setValue("integer_interpolation", option)
+        self._settings.setValue("mdf/integer_interpolation", option)
 
         option = int(option[0])
         self.integer_interpolation = option
@@ -1082,7 +1101,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         self.batch.integer_interpolation = option
 
     def set_float_interpolation(self, option):
-        self._settings.setValue("float_interpolation", option)
+        self._settings.setValue("mdf/float_interpolation", option)
 
         option = int(option[0])
         self.float_interpolation = option
@@ -1095,7 +1114,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         self.batch.float_interpolation = option
 
     def set_plot_xaxis(self, option):
-        self._settings.setValue("plot_xaxis", option)
+        self._settings.setValue("plot/xaxis_units", option)
         if option == "seconds":
             fmt = "phys"
         elif option == "time":
@@ -1120,7 +1139,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
                     plot.range_modified(plot.plot.region)
 
     def set_theme(self, option):
-        self._settings.setValue("theme", option)
+        self._settings.setValue("interface/theme", option)
         app = QtWidgets.QApplication.instance()
         if option == "Light":
             app.setPalette(self._light_palette)
@@ -1270,7 +1289,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             app.setPalette(palette)
 
     def set_line_interconnect(self, option):
-        self._settings.setValue("line_interconnect", option)
+        self._settings.setValue("plot/curve/line_interconnect", option)
 
         self.line_interconnect = option
 
@@ -1283,7 +1302,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         if isinstance(state, str):
             state = True if state == "true" else False
         self.set_subplots_link(state)
-        self._settings.setValue("subplots_link", state)
+        self._settings.setValue("mdf/subwindows_link", state)
         count = self.files.count()
 
         for i in range(count):
@@ -1292,7 +1311,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
     def set_tabular_interpolation_option(self, state):
         if isinstance(state, str):
             state = True if state == "true" else False
-        self._settings.setValue("tabular_interpolation", state)
+        self._settings.setValue("tabular/interpolation", state)
 
     def set_ignore_value2text_conversions_option(self, state):
         if isinstance(state, str):
@@ -1305,6 +1324,20 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             self.files.widget(i).ignore_value2text_conversions = state
         self.batch.ignore_value2text_conversions = state
 
+    def set_invalidation_bits_option(self, state):
+        if isinstance(state, str):
+            state = True if state == "true" else False
+        self.ignore_invalidation_bits = state
+        self._settings.setValue("ignore_invalidation_bits", state)
+
+    def set_check_unsaved_display(self, state):
+        if isinstance(state, str):
+            state = True if state == "true" else False
+        self.check_unsaved_display = state
+        self._settings.setValue("check_unsaved_display", state)
+
+        set_global_option("check_unsaved_display_file", state)
+
     def set_display_cg_name_option(self, state):
         if isinstance(state, str):
             state = True if state == "true" else False
@@ -1367,10 +1400,11 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
                     self.ignore_value2text_conversions,
                     self.display_cg_name,
                     self.line_interconnect,
-                    1,
-                    None,
                     None,
+                    False,
+                    False,
                     self,
+                    ignore_invalidation_bits=self.ignore_invalidation_bits,
                 )
 
             except:
@@ -1382,9 +1416,10 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
                 self.files.setCurrentIndex(index)
                 widget.open_new_files.connect(self._open_file)
                 widget.full_screen_toggled.connect(self.toggle_fullscreen)
-
                 self.edit_cursor_options()
 
+                widget.finalize_init()
+
     def open_file(self, event):
         system = platform.system().lower()
         if system == "linux":
@@ -1513,8 +1548,8 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
 
                 dlg = MultiSearch(measurements, parent=self)
                 dlg.setModal(True)
-                dlg.exec_()
-                result = dlg.result
+                dlg.exec()
+                result = dlg.payload
                 if result:
                     options = [
                         "New plot window",
@@ -1528,7 +1563,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
 
                     dialog = WindowSelectionDialog(options=options, default=default, parent=self)
                     dialog.setModal(True)
-                    dialog.exec_()
+                    dialog.exec()
 
                     if dialog.result():
                         window_type = dialog.selected_type()
@@ -1618,7 +1653,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
                 widget.autofit_sub_plots()
 
                 self.with_dots = widget.with_dots
-                self._settings.setValue("dots", self.with_dots)
+                self._settings.setValue("plot/dots", self.with_dots)
 
                 count = self.files.count()
 
@@ -1668,7 +1703,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
                     file.functions, channels, parent=self, global_variables=file.global_variables
                 )
                 dlg.setModal(True)
-                dlg.exec_()
+                dlg.exec()
 
                 if dlg.pressed_button == "apply":
                     original_definitions = dlg.original_definitions
@@ -1686,7 +1721,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
     def bus_database_manager(self):
         dlg = BusDatabaseManagerDialog(parent=self)
         dlg.setModal(True)
-        dlg.exec_()
+        dlg.exec()
 
         if dlg.pressed_button == "apply":
             dlg.store()
