@@ -7,11 +7,15 @@ from PySide6.QtTest import QTest
 from PySide6.QtWidgets import QMessageBox
 
 from asammdf.gui.serde import COLORS
-from test.asammdf.gui.test_base import Pixmap
+from asammdf.gui.widgets.plot import Plot
+from test.asammdf.gui.test_base import Pixmap, safe_setup
 from test.asammdf.gui.widgets.test_BasePlotWidget import TestPlotWidget
 
 
 class TestPlotShortcuts(TestPlotWidget):
+    plot: Plot
+
+    @safe_setup
     def setUp(self):
         """
         Events:
@@ -144,58 +148,51 @@ class TestPlotShortcuts(TestPlotWidget):
             QTest.mouseClick(self.plot.focused_mode_btn, Qt.MouseButton.LeftButton)
         # add channels to plot
         self.assertIsNotNone(self.add_channels([35, 36, 37]))
-        pixmap = self.plot.plot.viewport().grab()
+        colors = [ch.color.name() for ch in self.channels]
+
         # Evaluate
-        self.assertTrue(Pixmap.has_color(pixmap, self.channels[0].color.name()))
-        self.assertTrue(Pixmap.has_color(pixmap, self.channels[1].color.name()))
-        self.assertTrue(Pixmap.has_color(pixmap, self.channels[2].color.name()))
+        # If all colors exists
+        self.assertTrue(self.is_not_blinking(self.plot.plot, set(colors)))
 
         # case 0
         QTest.keySequence(self.plot, QKeySequence(self.shortcuts["focused_mode"]))
-        self.processEvents(1)
-        for _ in range(100):
-            self.processEvents(0.01)
+        self.processEvents(0.1)
         # Evaluate
         self.assertTrue(Pixmap.is_black(self.plot.plot.viewport().grab()))
 
         # case 1
         self.mouseClick_WidgetItem(self.channels[0])
-        for _ in range(50):
-            self.avoid_blinking_issue(self.plot.channel_selection)
-        pixmap = self.plot.plot.viewport().grab()
+
         # Evaluate
-        self.assertTrue(Pixmap.has_color(pixmap, self.channels[0].color.name()))
-        self.assertFalse(Pixmap.has_color(pixmap, self.channels[1].color.name()))
-        self.assertFalse(Pixmap.has_color(pixmap, self.channels[2].color.name()))
+        self.assertTrue(self.is_not_blinking(self.plot.plot, {colors[0]}))
+        self.assertFalse(
+            {colors[1], colors[2]}.issubset(Pixmap.color_names_exclude_defaults(self.plot.plot.viewport().grab()))
+        )
 
         # case 2
-        QTest.keyClick(self.plot.channel_selection, Qt.Key_Down)
-        for _ in range(50):
-            self.avoid_blinking_issue(self.plot.channel_selection)
-        pixmap = self.plot.plot.viewport().grab()
+        QTest.keyClick(self.plot.channel_selection, Qt.Key.Key_Down)
+
         # Evaluate
-        self.assertFalse(Pixmap.has_color(pixmap, self.channels[0].color.name()))
-        self.assertTrue(Pixmap.has_color(pixmap, self.channels[1].color.name()))
-        self.assertFalse(Pixmap.has_color(pixmap, self.channels[2].color.name()))
+        self.assertTrue(self.is_not_blinking(self.plot.plot, {colors[1]}))
+        self.assertFalse(
+            {colors[0], colors[2]}.issubset(Pixmap.color_names_exclude_defaults(self.plot.plot.viewport().grab()))
+        )
 
         # case 3
         self.mouseClick_WidgetItem(self.channels[2])
-        for _ in range(50):
-            self.avoid_blinking_issue(self.plot.channel_selection)
-        pixmap = self.plot.plot.viewport().grab()
-        # Evaluate
-        self.assertFalse(Pixmap.has_color(pixmap, self.channels[0].color.name()))
-        self.assertFalse(Pixmap.has_color(pixmap, self.channels[1].color.name()))
-        self.assertTrue(Pixmap.has_color(pixmap, self.channels[2].color.name()))
 
-        # case 4
-        QTest.keySequence(self.plot, QKeySequence(self.shortcuts["focused_mode"]))
-        self.processEvents(0.1)
-        pixmap = self.plot.plot.viewport().grab()
         # Evaluate
-        self.assertTrue(Pixmap.has_color(pixmap, self.channels[0].color.name()))
-        self.assertTrue(Pixmap.has_color(pixmap, self.channels[1].color.name()))
-        self.assertTrue(Pixmap.has_color(pixmap, self.channels[2].color.name()))
+        self.assertTrue(self.is_not_blinking(self.plot.plot, {colors[2]}))
+        self.assertFalse(
+            {colors[1], colors[0]}.issubset(Pixmap.color_names_exclude_defaults(self.plot.plot.viewport().grab()))
+        )
+
+        # case 4 - exit focused mode
+        QTest.keySequence(self.plot, QKeySequence(self.shortcuts["focused_mode"]))
+
+        self.processEvents(0.1)
+        # Evaluate
+        self.assertTrue(self.is_not_blinking(self.plot.plot, set(colors)))
 
     def test_ascii__bin__hex__physical_shortcuts(self):
         """
@@ -658,7 +655,6 @@ class TestPlotShortcuts(TestPlotWidget):
 
         # Events
         self.mouseClick_WidgetItem(self.channels[0])
-        self.avoid_blinking_issue(self.plot.channel_selection)
         # Click in the center of the plot
         QTest.mouseClick(
             self.plot.plot.viewport(),
