@@ -3,19 +3,19 @@ import json
 from json import JSONDecodeError
 import pathlib
 import re
-import sys
-import unittest
 from unittest import mock
 from unittest.mock import ANY
 
 from PySide6 import QtCore, QtGui, QtTest, QtWidgets
 
+from test.asammdf.gui.test_base import safe_setup
 from test.asammdf.gui.widgets.test_BasePlotWidget import TestPlotWidget
 
 
 class TestContextMenu(TestPlotWidget):
     # Note: Test Plot Widget through FileWidget.
 
+    @safe_setup
     def setUp(self):
         super().setUp()
 
@@ -846,7 +846,6 @@ class TestContextMenu(TestPlotWidget):
             self.assertNotEqual(previous_c_color, current_c_color)
             self.assertNotEqual(current_b_color, current_c_color)
 
-    @unittest.skipIf(sys.platform == "win32", "times out on Windows")
     def test_Action_CopyDisplayProperties_Group(self):
         """
         Test Scope:
@@ -1047,7 +1046,6 @@ class TestContextMenu(TestPlotWidget):
             # Evaluate
             self.assertEqual(group_channel_a_properties, group_channel_b_properties)
 
-    @unittest.skipIf(sys.platform == "win32", "times out on Windows")
     def test_Action_CopyChannelStructure_Group(self):
         """
         Test Scope:
